hive-photocraft.transport.socket

Authenticated, bounded loopback control channel adapter.

Authenticated, bounded loopback control channel adapter.
raw docstring

default-configclj

Per-attempt socket bounds and protocol frame ceilings.

Per-attempt socket bounds and protocol frame ceilings.
sourceraw docstring

socket-transportclj

(socket-transport config)

Construct a loopback adapter from a port and a required file or environment secret reference.

Construct a loopback adapter from a port and a required file or environment secret reference.
sourceraw docstring

token-ref?clj

(token-ref? ref)

Whether a configuration has a supported secret reference (not a token value).

Whether a configuration has a supported secret reference (not a token value).
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries