Effect port for sending one already-validated PhotoCraft control request.
Effect port for sending one already-validated PhotoCraft control request.
(send-request this request)Send a single request and return a reply map; never silently retry an edit.
Send a single request and return a reply map; never silently retry an edit.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |