Authenticated, bounded loopback control channel adapter.
Authenticated, bounded loopback control channel adapter.
Per-attempt socket bounds and protocol frame ceilings.
Per-attempt socket bounds and protocol frame ceilings.
(socket-transport config)Construct a loopback adapter from a port and a required file or environment secret reference.
Construct a loopback adapter from a port and a required file or environment secret reference.
(token-ref? ref)Whether a configuration has a supported secret reference (not a token value).
Whether a configuration has a supported secret reference (not a token value).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |